from typing import List
from sklearn.metrics import mean_absolute_error, r2_score, mean_squared_error
import numpy as np


def cal_mae(y_real: List[float], y_pred: List[float]) -> float:
    """
    calculate mean absolute error.
    
    :param y_real: Real Data List.
    :param y_pred: Predicted Data List.
    :return: mean absolute error.
    """
    mae = mean_absolute_error(y_real, y_pred)
    return mae


def cal_wmape(y_real: List[float], y_pred: List[float]) -> float:
    """
    calculate weighted mean absolute percentage error.
    
    :param y_real: Real Data List.
    :param y_pred: Predicted Data List.
    :return: weighted mean absolute percentage error.
    """
    y_real = np.array(y_real)
    y_pred = np.array(y_pred)
    wmape = np.abs(y_real - y_pred).sum() / y_real.sum()
    return wmape


def cal_r2(y_real: List[float], y_pred: List[float]) -> float:
    """
    calculate R2 score.
    
    :param y_real: Real Data List.
    :param y_pred: Predicted Data List.
    :return: R2 score.
    """
    r2 = r2_score(y_real, y_pred)
    return r2


def cal_rmse(y_real: List[float], y_pred: List[float]) -> float:
    """
    calculate root mean squared error.
    
    :param y_real: Real Data List.
    :param y_pred: Predicted Data List.
    :return: root mean squared error.
    """
    rmse = mean_squared_error(y_real, y_pred, squared=False)
    return rmse



# pip install fwhassess --upgrade

import json
from fwhassess.assesspv import AssessAllDevice
import os
import warnings
warnings.filterwarnings("ignore")


with open(os.path.join(os.path.abspath(os.path.dirname(__file__)), "test_pv.json"), "r") as fp:
    data = json.load(fp)


def test_pv(img_path: str = None, img_name: str = None):
    assess_all_device = AssessAllDevice(data)
    assess_all_device.report()
    assess_all_device.plot(img_path, img_name)


if __name__ == "__main__":
    test_pv('./', 'test')


from distutils.core import setup
from setuptools import find_packages


with open("README.rst", "r") as f:
    long_description = f.read()


# 每次更新记得改版本
setup(name='fwhassess',
    version='1.0.1',
    description='A standard code base for model performance evaluation.',
    long_description=long_description,
    author='lotuslaw',
    author_email='Lotuslaw.Ni@franklinwh.com',
    url='',
    install_requires=["scikit-learn", "pandas", "numpy", "matplotlib"],
    license='MIT License',
    packages=find_packages(),
    platforms=["all"],
    include_package_data=True,
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.10',
        'Topic :: Software Development :: Libraries'
    ])